<?php
// Exit if accessed directly
if (!defined('ABSPATH')) exit;

class Vizou_Events_Shortcodes {
    public static function register() {
        // Register the old shortcode for backward compatibility - to be removed soon!
        add_shortcode('showdates', array(__CLASS__, 'show_dates_shortcode'));    
        // Register the new, more intuitive shortcode name
        add_shortcode('vizou-events', array(__CLASS__, 'show_dates_shortcode'));
    }
    
    public static function show_dates_shortcode($atts, $content = null) {
        wp_enqueue_style('vizou-events-manager');
        
        $today = current_time('Y-m-d');
        $atts = shortcode_atts(array(
            'show' => 'upcoming',
            'year' => '',
            'order' => 'asc',
            'limit' => -1,
            'tour' => '',
            'artist' => ''
        ), $atts, 'showdates');

        $args = array(
            'post_type' => 'event',
            'posts_per_page' => intval($atts['limit']),
            'meta_key' => 'event_start',
            'orderby' => 'meta_value',
            'order' => (strtolower($atts['order']) === 'desc') ? 'DESC' : 'ASC',
            'meta_query' => array(
                'relation' => 'AND'
            ),
            'tax_query' => array(
                'relation' => 'AND'
            )
        );

        // Add tour filter if tour_id is provided
        if (!empty($atts['tour'])) {
            $args['tax_query'][] = array(
                'taxonomy' => 'tour',
                'field' => 'term_id',
                'terms' => intval($atts['tour'])
            );
        }

        // Add artist filter if artist_id is provided
        if (!empty($atts['artist'])) {
            $args['tax_query'][] = array(
                'taxonomy' => 'artist',
                'field' => 'term_id',
                'terms' => intval($atts['artist'])
            );
        }

        switch($atts['show']) {
            case 'past':
                $args['meta_query'][] = array(
                    'key' => 'event_start',
                    'compare' => '<',
                    'value' => $today,
                    'type' => 'DATE'
                );
                $args['order'] = 'DESC';
                break;
            case 'all':
                break;
            case 'upcoming':
            default:
                $args['meta_query'][] = array(
                    'key' => 'event_start',
                    'compare' => '>=',
                    'value' => $today,
                    'type' => 'DATE'
                );
                break;
        }

        if (!empty($atts['year'])) {
            $args['meta_query'][] = array(
                'key' => 'event_start',
                'compare' => 'BETWEEN',
                'value' => array($atts['year'] . '-01-01', $atts['year'] . '-12-31'),
                'type' => 'DATE'
            );
        }

        $query = new WP_Query($args);
        
        ob_start();
        echo '<div class="vizou-events-container">';

        if ($query->have_posts()) {
            while ($query->have_posts()) {
                $query->the_post();
                
                // First check for theme override template
                $theme_template = locate_template('vizou-events/vizou-events-list.php');
                
                if ($theme_template && file_exists($theme_template)) {
                    // Use the theme's override template
                    include $theme_template;
                } else {
                    // If no theme override exists, use the plugin's default template
                    $default_template = vizou_events_manager()->get_template_path('vizou-events-list.php');
                    if ($default_template && file_exists($default_template)) {
                        include $default_template;
                    } else {
                        // Emergency fallback if default template is not found
                        echo "<!-- Template not found for event ID: " . esc_html(get_the_ID()) . " -->";
                    }
                }
            }
        } else {
            echo '<p class="no-events">' . esc_html(Vizou_Events_Settings::get_option('no_events_text')) . '</p>';
        }

        // Close the container
        echo '</div>';

        wp_reset_postdata();
        return ob_get_clean();
    }
}